@@ -1,17 +1,20 @@
 from __future__ import annotations
 
 import json
-import sys
 import os
+import re
+import sys
+import time
+import unicodedata
+from importlib import metadata as _im
 from pathlib import Path
 from typing import Any, Dict, List, Optional, Tuple
 
 import typer
-from importlib import metadata as _im
 import yaml
 
 from drun.loader.collector import discover, match_tags
-from drun.loader.yaml_loader import expand_parameters, load_yaml_file
+from drun.loader.yaml_loader import expand_parameters, load_yaml_file, strip_escape_quotes, format_variables_multiline
 from drun.loader.hooks import get_functions_for
 from drun.loader.env import load_environment
 from drun.models.case import Case
@@ -23,11 +26,31 @@ from drun.models.report import RunReport
 from drun.reporter.json_reporter import write_json
 from drun.runner.runner import Runner
 from drun.templating.engine import TemplateEngine
-from drun.utils.logging import setup_logging, get_logger
-import time
-
-
+from drun.utils.config import get_env_clean, get_system_name
 from drun.utils.errors import LoadError
+from drun.utils.logging import setup_logging, get_logger
+
+
+def _sanitize_filename_component(value: str, fallback: str) -> str:
+    value = (value or "").strip()
+    if not value:
+        return fallback
+    normalized = unicodedata.normalize("NFKC", value)
+    invalid_chars = {'<', '>', ':', '"', '/', '\\', '|', '?', '*'}
+    cleaned_chars = []
+    for ch in normalized.lower():
+        if ord(ch) < 32:
+            cleaned_chars.append("-")
+            continue
+        if ch in invalid_chars:
+            cleaned_chars.append("-")
+            continue
+        cleaned_chars.append(ch)
+    candidate = "".join(cleaned_chars)
+    candidate = re.sub(r"\s+", "-", candidate)
+    candidate = re.sub(r"-{2,}", "-", candidate)
+    candidate = candidate.strip(" .-")
+    return candidate or fallback
 
 
 def _resolve_env_file_alias(value: str) -> tuple[str, bool, List[str]]:
@@ -318,6 +341,13 @@ def _to_yaml_case_dict(case: Case) -> Dict[str, object]:
                     reordered[key] = value
             step["request"] = reordered
 
+        # Remove unnecessary default fields from request
+        req = step.get("request", {})
+        if "stream" in req and req["stream"] is False:
+            req.pop("stream", None)
+        if "stream_timeout" in req and req.get("stream_timeout") is None:
+            req.pop("stream_timeout", None)
+
         if step_validators:
             step["validate"] = step_validators
 
@@ -961,7 +991,9 @@ def export_curl(
 
     output = "\n\n".join(out_lines)
     if outfile:
-        Path(outfile).write_text(output, encoding="utf-8")
+        out_path = Path(outfile)
+        out_path.parent.mkdir(parents=True, exist_ok=True)
+        out_path.write_text(output, encoding="utf-8")
         typer.echo(f"[EXPORT] Wrote {len(out_lines)} curl commands to {outfile}")
     else:
         typer.echo(output)
@@ -1070,10 +1102,10 @@ def run(
     notify_attach_html: bool = typer.Option(False, "--notify-attach-html/--no-notify-attach-html", help="在邮件中附加 HTML 报告（如果启用邮件）", show_default=False),
 ):
     """运行测试用例或测试套件"""
-    # default log file path
+    # default timestamp; set up console logging first (no file) to avoid writing to a wrong file
     ts = time.strftime("%Y%m%d-%H%M%S")
-    default_log = log_file or f"logs/run-{ts}.log"
-    setup_logging(log_level, log_file=default_log)
+    default_log = None  # will be decided after env is loaded
+    setup_logging(log_level, log_file=None)
     log = get_logger("drun.cli")
     # unify httpx logs: default suppress, unless enabled
     import logging as _logging
@@ -1106,6 +1138,14 @@ def run(
     for env_key, env_val in env_store.items():
         if env_key and isinstance(env_val, str) and env_key.upper() == env_key:  # Only uppercase keys (skip lowercase duplicates)
             os.environ.setdefault(env_key, env_val)
+
+    # Now compute system-specific log file after env is loaded (so SYSTEM_NAME/PROJECT_NAME are visible)
+    system_name = get_system_name()
+    log_component = _sanitize_filename_component(system_name, "run")
+    default_log = log_file or f"logs/{log_component}-{ts}.log"
+    # reconfigure logging with file handler now that we know the correct path
+    setup_logging(log_level, log_file=default_log)
+    log = get_logger("drun.cli")
     # Preflight: warn when default env file is missing and no BASE_URL provided anywhere
     from pathlib import Path as _Path
     _env_exists = _Path(env_file).exists() if env_file else False
@@ -1130,7 +1170,7 @@ def run(
     # confusing behavior (e.g., `-k auth` ignored if ENV has AUTH/auth).
     # That heuristic is removed to ensure explicit filters are respected.
     # Discover files
-    typer.echo(f"Filter expression: {k!r}")
+    log.info(f"[FILTER] expression: {k!r}")
     files = discover([path])
     if not files:
         from pathlib import Path as _Path
@@ -1242,6 +1282,18 @@ def run(
                     typer.echo(line)
                 raise typer.Exit(code=2)
             log.info(f"[CASE] Start: {c.config.name or 'Unnamed'} | params={ps}")
+
+            # Print base_url if present
+            if c.config.base_url:
+                log.info(f"[CONFIG] base_url: {c.config.base_url}")
+
+            # Print config variables if present
+            if c.config.variables:
+                vars_str = format_variables_multiline(c.config.variables, "[CONFIG] variables: ")
+                for line in vars_str.split("\n"):
+                    if line.strip():
+                        log.info(line)
+
             res = runner.run_case(c, global_vars=global_vars, params=ps, funcs=funcs, envmap=env_store, source=meta.get("file"))
             log.info(f"[CASE] Result: {res.name} | status={res.status} | duration={res.duration_ms:.1f}ms")
             instance_results.append(res)
@@ -1264,7 +1316,8 @@ def run(
             s.get("steps_skipped", 0),
         )
 
-    html_target = html or f"reports/report-{ts}.html"
+    html_component = _sanitize_filename_component(system_name, "report")
+    html_target = html or f"reports/{html_component}-{ts}.html"
 
     if report:
         write_json(report_obj, report)
@@ -1292,15 +1345,22 @@ def run(
             build_summary_text,
         )
 
-        channels_spec = notify if notify is not None else os.environ.get("DRUN_NOTIFY", "")
+        env_channels = get_env_clean("DRUN_NOTIFY") or ""
+        channels_spec = notify.strip() if (notify and notify.strip()) else env_channels
         channels = [c.strip().lower() for c in channels_spec.split(",") if c.strip()]
+
+        feishu_webhook = get_env_clean("FEISHU_WEBHOOK")
+        dingtalk_webhook = get_env_clean("DINGTALK_WEBHOOK")
+        smtp_host_env = get_env_clean("SMTP_HOST")
+        mail_to_env = get_env_clean("MAIL_TO")
+
         if not channels:
             auto_channels: List[str] = []
-            if os.environ.get("FEISHU_WEBHOOK"):
+            if feishu_webhook:
                 auto_channels.append("feishu")
-            if os.environ.get("DINGTALK_WEBHOOK"):
+            if dingtalk_webhook:
                 auto_channels.append("dingtalk")
-            if os.environ.get("SMTP_HOST") or os.environ.get("MAIL_TO"):
+            if smtp_host_env or mail_to_env:
                 auto_channels.append("email")
             if auto_channels:
                 log.info("[NOTIFY] Auto-enabling channels from environment: %s", ", ".join(auto_channels))
@@ -1308,8 +1368,10 @@ def run(
         # deduplicate while preserving order
         seen = set()
         channels = [c for c in channels if not (c in seen or seen.add(c))]
-        policy = (notify_only or os.environ.get("DRUN_NOTIFY_ONLY", "failed")).strip().lower()
-        topn = int(os.environ.get("NOTIFY_TOPN", "5") or "5")
+        policy_source = notify_only.strip() if (notify_only and notify_only.strip()) else get_env_clean("DRUN_NOTIFY_ONLY", "failed")
+        policy = (policy_source or "failed").lower()
+        topn_raw = get_env_clean("NOTIFY_TOPN", "5") or "5"
+        topn = int(topn_raw)
 
         log.info("[NOTIFY] channels=%s policy=%s", channels, policy)
 
@@ -1324,41 +1386,44 @@ def run(
             notifiers = []
 
             if "feishu" in channels:
-                fw = os.environ.get("FEISHU_WEBHOOK", "").strip()
+                fw = feishu_webhook or ""
                 if fw:
-                    fs = os.environ.get("FEISHU_SECRET")
-                    fm = os.environ.get("FEISHU_MENTION")
-                    style = os.environ.get("FEISHU_STYLE", "text").lower().strip()
+                    fs = get_env_clean("FEISHU_SECRET")
+                    fm = get_env_clean("FEISHU_MENTION")
+                    style = (get_env_clean("FEISHU_STYLE", "text") or "text").lower()
                     notifiers.append(FeishuNotifier(webhook=fw, secret=fs, mentions=fm, style=style))
                     log.info("[NOTIFY] Feishu notifier created (style=%s)", style)
                 else:
                     log.warning("[NOTIFY] Feishu channel requested but FEISHU_WEBHOOK not configured")
 
             if "email" in channels:
-                host = os.environ.get("SMTP_HOST", "").strip()
+                host = smtp_host_env or ""
                 if host:
                     notifiers.append(
                         EmailNotifier(
                             smtp_host=host,
-                            smtp_port=int(os.environ.get("SMTP_PORT", "465") or 465),
-                            smtp_user=os.environ.get("SMTP_USER"),
-                            smtp_pass=os.environ.get("SMTP_PASS"),
-                            mail_from=os.environ.get("MAIL_FROM"),
-                            mail_to=os.environ.get("MAIL_TO"),
-                            use_ssl=(os.environ.get("SMTP_SSL", "true").lower() != "false"),
-                            attach_html=bool(notify_attach_html or (os.environ.get("NOTIFY_ATTACH_HTML", "").lower() in {"1","true","yes"})),
-                            html_body=(os.environ.get("NOTIFY_HTML_BODY", "true").lower() != "false"),
+                            smtp_port=int(get_env_clean("SMTP_PORT", "465") or 465),
+                            smtp_user=get_env_clean("SMTP_USER"),
+                            smtp_pass=get_env_clean("SMTP_PASS"),
+                            mail_from=get_env_clean("MAIL_FROM"),
+                            mail_to=mail_to_env,
+                            use_ssl=((get_env_clean("SMTP_SSL", "true") or "true").lower() != "false"),
+                            attach_html=bool(
+                                notify_attach_html
+                                or ((get_env_clean("NOTIFY_ATTACH_HTML") or "").lower() in {"1", "true", "yes"})
+                            ),
+                            html_body=((get_env_clean("NOTIFY_HTML_BODY", "true") or "true").lower() != "false"),
                         )
                     )
 
             if "dingtalk" in channels:
-                dw = os.environ.get("DINGTALK_WEBHOOK", "").strip()
+                dw = dingtalk_webhook or ""
                 if dw:
-                    ds = os.environ.get("DINGTALK_SECRET")
-                    mobiles = os.environ.get("DINGTALK_AT_MOBILES", "").strip()
+                    ds = get_env_clean("DINGTALK_SECRET")
+                    mobiles = get_env_clean("DINGTALK_AT_MOBILES") or ""
                     at_mobiles = [m.strip() for m in mobiles.split(",") if m.strip()]
-                    at_all = os.environ.get("DINGTALK_AT_ALL", "").lower() in {"1", "true", "yes"}
-                    style = os.environ.get("DINGTALK_STYLE", "text").lower().strip()
+                    at_all = (get_env_clean("DINGTALK_AT_ALL") or "").lower() in {"1", "true", "yes"}
+                    style = (get_env_clean("DINGTALK_STYLE", "text") or "text").lower()
                     notifiers.append(
                         DingTalkNotifier(webhook=dw, secret=ds, at_mobiles=at_mobiles, at_all=at_all, style=style)
                     )
@@ -1677,7 +1742,7 @@ def init_project(
     from drun import scaffolds
     
     # Display version
-    typer.echo(f"Drun v{_get_drun_version()}\n")
+    typer.echo(f"Drun v{_get_drun_version()}")
 
     # 确定目标目录
     if name:
@@ -1712,6 +1777,7 @@ def init_project(
         "converts": "格式转换源文件目录",
         "reports": "报告输出目录",
         "logs": "日志输出目录",
+        ".github/workflows": "GitHub Actions 工作流目录",
     }
 
     for dir_name, desc in dirs_to_create.items():
@@ -1752,6 +1818,9 @@ def init_project(
     # testcases/test_stream.yaml
     _write_template("testcases/test_stream.yaml", scaffolds.STREAM_TESTCASE)
 
+    # testcases/test_assertions.yaml
+    _write_template("testcases/test_assertions.yaml", scaffolds.ASSERTIONS_TESTCASE)
+
     # data/users.csv
     _write_template("data/users.csv", scaffolds.CSV_USERS_SAMPLE)
 
@@ -1797,6 +1866,12 @@ def init_project(
     # README.md
     _write_template("README.md", scaffolds.README_TEMPLATE)
 
+    # GitHub Actions workflow
+    _write_template(".github/workflows/test.yml", scaffolds.GITHUB_WORKFLOW_TEMPLATE)
+
+    # GitLab CI pipeline
+    _write_template(".gitlab-ci.yml", scaffolds.GITLAB_CI_TEMPLATE)
+
     # 输出创建的文件列表（tree 风格）
     project_name = name if name else "."
 
@@ -1806,7 +1881,8 @@ def init_project(
         ("│   ├── ", "test_api_health.yaml", "健康检查示例"),
         ("│   ├── ", "test_stream.yaml", "流式响应 (SSE) 示例"),
         ("│   ├── ", "test_db_assert.yaml", "数据库断言示例"),
-        ("│   └── ", "test_import_users.yaml", "CSV 参数化示例"),
+        ("│   ├── ", "test_import_users.yaml", "CSV 参数化示例"),
+        ("│   └── ", "test_assertions.yaml", "断言操作符完整示例"),
         ("├── ", "testsuites/", ""),
         ("│   ├── ", "testsuite_smoke.yaml", "冒烟测试套件"),
         ("│   └── ", "testsuite_csv.yaml", "CSV 示例套件"),
@@ -1825,6 +1901,10 @@ def init_project(
         ("│       └── ", "sample_openapi.json", "OpenAPI 规范"),
         ("├── ", "reports/", "测试报告输出目录"),
         ("├── ", "logs/", "运行日志输出目录"),
+        ("├── ", ".github/", "GitHub 配置目录"),
+        ("│   └── ", "workflows/", "GitHub Actions 工作流"),
+        ("│       └── ", "test.yml", "默认 CI 流水线"),
+        ("├── ", ".gitlab-ci.yml", "GitLab CI 流水线"),
         ("├── ", ".env", "环境变量配置"),
         ("├── ", "drun_hooks.py", "自定义 Hooks 函数"),
         ("├── ", ".gitignore", "Git 忽略规则"),
@@ -1841,7 +1921,7 @@ def init_project(
         else:
             typer.echo(full)
     typer.echo("")
-    typer.echo("9 directories, 17 files")
+    typer.echo("9 directories, 19 files")
 
     if skipped_files:
         typer.echo("")
@@ -1862,20 +1942,10 @@ def init_project(
     if name:
         typer.echo(f"  cd {name}")
     typer.echo("  drun run testcases/test_api_health.yaml")
-    # httpstat 功能已删除
-    typer.echo("  drun run testcases/test_stream.yaml      # 流式响应 (SSE) 示例")
-    typer.echo("  drun run testcases/test_db_assert.yaml   # 数据库断言示例")
-    typer.echo("  drun run testcases/test_import_users.yaml  # CSV 数据驱动示例")
-    typer.echo("")
-    typer.echo("格式转换 (查看 converts/README.md 获取详细说明):")
-    typer.echo("  - cURL 转用例:")
-    typer.echo("    drun convert converts/curl/sample.curl --outfile testcases/new_test.yaml")
-    typer.echo("  - Postman 转用例:")
-    typer.echo("    drun convert converts/postman/sample_collection.json --split-output --suite-out testsuites/new_suite.yaml")
-    typer.echo("  - HAR 转用例:")
-    typer.echo("    drun convert converts/har/sample_recording.har --exclude-static --only-2xx --outfile testcases/from_har.yaml")
-    typer.echo("  - OpenAPI 转用例:")
-    typer.echo("    drun convert-openapi converts/openapi/sample_openapi.json --split-output --outfile testcases/from_openapi.yaml")
+    typer.echo("  drun run testcases/test_stream.yaml")
+    typer.echo("  drun run testcases/test_db_assert.yaml")
+    typer.echo("  drun run testcases/test_import_users.yaml")
+    typer.echo("  drun run testcases/test_assertions.yaml")
     typer.echo("")
     typer.echo("文档: https://github.com/Devliang24/drun")
 
