@@ -24,6 +24,130 @@ def _is_testsuite_reference(doc: Dict[str, Any]) -> bool:
     return isinstance(doc, dict) and isinstance(doc.get("testcases"), list)
 
 
+def _escape_template_expressions_in_yaml(raw_text: str) -> str:
+    """
+    Temporarily escape template expressions to ensure safe YAML parsing.
+
+    When template expressions like ${func(...)} appear in arrays/lists,
+    YAML parser may get confused by special characters like parentheses.
+    We wrap such expressions in double quotes to ensure safe parsing.
+    """
+    import re
+
+    # Pattern to match template expressions that need escaping
+    # Look for ${...} patterns that contain parentheses (function calls)
+    pattern = r'\$\{[^}]*\([^)]*\)[^}]*\}'
+
+    def replace_template(match):
+        full_match = match.group(0)
+        # Check if the template expression is already quoted
+        # Look for quotes right before the ${...} pattern
+        start_pos = match.start()
+        if start_pos > 0 and raw_text[start_pos - 1] in ('"', "'"):
+            return full_match
+        # Wrap in double quotes to escape special chars
+        return f'"{full_match}"'
+
+    return re.sub(pattern, replace_template, raw_text)
+
+
+def strip_escape_quotes(value: str) -> str:
+    """
+    Strip escape quotes from template expressions for display purposes.
+
+    When displaying variables, we want to show clean values without the
+    escape quotes that were added during YAML parsing.
+
+    Args:
+        value: The value that may contain escape quotes
+
+    Returns:
+        Value with escape quotes removed if present
+    """
+    import re
+
+    # Pattern to match escaped template expressions: "${...}"
+    # This handles both:
+    # 1. Full value is just a template: "${func()}"
+    # 2. Template is part of a larger string: text_"${func()}" or text_"${func()}"_more
+    pattern = r'"(\$\{[^}]*\})"'
+
+    def replace_escaped_template(match):
+        # Return just the template part without the wrapping quotes
+        return match.group(1)
+
+    # Replace all occurrences of "template" with just template
+    result = re.sub(pattern, replace_escaped_template, value)
+    return result
+
+
+def format_variables_multiline(variables: Dict[str, Any], prefix: str, max_line_length: int = 120) -> str:
+    """
+    Format variables into multi-line aligned display.
+
+    Args:
+        variables: Dictionary of variable name-value pairs
+        prefix: The prefix string (e.g., "[CONFIG] variables: ")
+        max_line_length: Maximum line length before wrapping (default: 120)
+
+    Returns:
+        Multi-line formatted string with proper alignment
+    """
+    if not variables:
+        return prefix.rstrip() if prefix.endswith(": ") else prefix
+
+    # Format all variable assignments
+    var_assignments = [f"{k}={strip_escape_quotes(str(v))}" for k, v in variables.items()]
+
+    # Calculate prefix length for alignment
+    prefix_len = len(prefix)
+
+    # Check if we can fit all variables on one line with the prefix
+    all_vars = ", ".join(var_assignments)
+    if prefix_len + len(all_vars) <= max_line_length:
+        # Fits on one line
+        return prefix + all_vars
+
+    # Need to split into multiple lines
+    lines = []
+
+    # First line: prefix + as many vars as fit
+    first_line_vars = []
+    current_length = prefix_len
+
+    for var in var_assignments:
+        # Add 2 for ", " separator (except for first item)
+        var_length = len(var) + (2 if first_line_vars else 0)
+        if current_length + var_length <= max_line_length:
+            first_line_vars.append(var)
+            current_length += var_length
+        else:
+            break
+
+    # Ensure first line has at least one variable
+    if not first_line_vars:
+        first_line_vars = [var_assignments[0]]
+        remaining_vars = var_assignments[1:]
+    else:
+        remaining_vars = var_assignments[len(first_line_vars):]
+
+    # Add the first line
+    lines.append(prefix + ", ".join(first_line_vars))
+
+    # Subsequent lines: space-prefix + as many vars as fit
+    for var in remaining_vars:
+        var_length = len(var) + 2  # +2 for ", " separator
+        if len(lines[-1]) + var_length <= max_line_length:
+            # Append to current line
+            lines[-1] += ", " + var
+        else:
+            # Start a new line
+            lines.append(" " * prefix_len + var)
+
+    return "\n".join(lines)
+
+
+
 def _normalize_case_dict(d: Dict[str, Any], path: Path | None = None, raw_text: str | None = None) -> Dict[str, Any]:
     dd = dict(d)
     has_top_level_parameters = "parameters" in dd
@@ -123,7 +247,11 @@ def _normalize_case_dict(d: Dict[str, Any], path: Path | None = None, raw_text:
 def load_yaml_file(path: Path) -> Tuple[List[Case], Dict[str, Any]]:
     try:
         raw = path.read_text(encoding="utf-8")
-        obj = yaml.safe_load(raw) or {}
+        # Pre-process YAML to escape template expressions that may cause parsing issues
+        # When template expressions like ${func(...)} appear in arrays/lists, they may confuse YAML parser
+        # We temporarily wrap them in quotes to ensure safe parsing
+        processed_raw = _escape_template_expressions_in_yaml(raw)
+        obj = yaml.safe_load(processed_raw) or {}
     except Exception as e:
         raise LoadError(f"Failed to parse YAML: {path}: {e}")
 
@@ -236,11 +364,11 @@ def load_yaml_file(path: Path) -> Tuple[List[Case], Dict[str, Any]]:
         raise LoadError("Legacy inline suite ('cases:') is not supported. Please use reference testsuite with 'testcases:'.")
     else:
         # single case file: normalize validators
-        obj = _normalize_case_dict(obj, path=path, raw_text=raw)
+        obj = _normalize_case_dict(obj, path=path, raw_text=processed_raw)
         try:
             case = Case.model_validate(obj)
         except ValidationError as exc:
-            raise LoadError(_format_case_validation_error(exc, obj, path, raw)) from exc
+            raise LoadError(_format_case_validation_error(exc, obj, path, processed_raw)) from exc
         cases.append(case)
 
     meta = {"file": str(path)}
@@ -423,10 +551,21 @@ def _find_request_subfield_location(raw_text: str, step_index: int, subfield: st
 
 
 def _resolve_csv_path(path_value: str, source_path: Path | None) -> Path:
+    from drun.loader.hooks import find_hooks
+
     candidate = Path(path_value).expanduser()
     if candidate.is_absolute():
         return candidate
-    base = Path(source_path).resolve().parent if source_path else Path.cwd()
+
+    base: Path | None = None
+    if source_path:
+        hooks_path = find_hooks(source_path)
+        if hooks_path:
+            base = hooks_path.parent.resolve()
+
+    if base is None:
+        base = Path.cwd().resolve()
+
     return (base / candidate).resolve()
 
 
