@@ -7,6 +7,7 @@ from pathlib import Path
 from typing import Any, List, Dict
 
 from drun.models.report import RunReport, CaseInstanceResult, StepResult, AssertionResult
+from drun.utils.config import get_system_name
 
 
 def _json(obj: Any) -> str:
@@ -44,14 +45,28 @@ def _escape_html(text: str) -> str:
     )
 
 
+def _format_assert_value(value: Any) -> str:
+    """Format assertion value: strings without quotes, others with JSON"""
+    if value is None:
+        return "null"
+    if isinstance(value, str):
+        return value
+    if isinstance(value, bool):
+        return "true" if value else "false"
+    if isinstance(value, (int, float)):
+        return str(value)
+    # For lists and dicts, use JSON formatting
+    return json.dumps(value, ensure_ascii=False)
+
+
 def _build_assert_table(asserts: List[AssertionResult]) -> str:
     rows = []
     for a in asserts or []:
         cells = [
             f"<td><code>{_escape_html(str(a.check))}</code></td>",
             f"<td><code>{_escape_html(str(a.comparator))}</code></td>",
-            f"<td><code>{_escape_html(json.dumps(a.expect, ensure_ascii=False))}</code></td>",
-            f"<td><code>{_escape_html(json.dumps(a.actual, ensure_ascii=False))}</code></td>",
+            f"<td><code>{_escape_html(_format_assert_value(a.expect))}</code></td>",
+            f"<td><code>{_escape_html(_format_assert_value(a.actual))}</code></td>",
             ("<td><span class='ok'>✓</span></td>" if a.passed else f"<td><span class='err' title='{_escape_html(a.message or '')}'>✗</span></td>")
         ]
         rows.append("<tr " + ("data-pass=1" if a.passed else "data-pass=0") + ">" + "".join(cells) + "</tr>")
@@ -380,12 +395,16 @@ def _build_case(case: CaseInstanceResult) -> str:
 
 
 def write_html(report: RunReport, outfile: str | Path) -> None:
+    from drun.utils.config import get_system_name
+
     s = report.summary or {}
     gen_time = time.strftime("%Y-%m-%d %H:%M:%S")
 
     # Header + styles (light theme, GitHub-like)
     head_parts = []
-    head_parts.append("""
+    system_name = get_system_name()
+    system_name_html = _escape_html(system_name)
+    head_template = """
 <!doctype html><html lang='zh-CN'><head><meta charset='utf-8' /><meta name='viewport' content='width=device-width, initial-scale=1' />
 <title>Drun 测试报告</title>
 <style>
@@ -428,14 +447,14 @@ def write_html(report: RunReport, outfile: str | Path) -> None:
   .panel .p-head { padding:6px 8px; background:var(--panel-head-bg); color:var(--muted); font-size:12px; display:flex; justify-content:space-between; align-items:center; }
   .panel .p-head .actions { display:flex; gap:6px; }
   .panel pre, .panel table { margin:0; padding:10px; overflow:auto; max-height: 360px; }
-  .panel[data-section='curl'] pre { white-space: pre-wrap; word-break: break-word; }
+  .panel[data-section='curl'] pre { white-space: pre; overflow-x: auto; word-break: normal; }
   table { width: 100%; border-collapse: collapse; table-layout: fixed; }
   th { padding: 6px 8px; border-bottom: 1px solid var(--border); vertical-align: top; text-align: left; font-weight: 600; }
   td { padding: 6px 8px; border-bottom: 1px solid var(--border); vertical-align: top; word-break: break-word; }
-  .assert-table th:nth-child(1), .assert-table td:nth-child(1) { width: 25%; }
-  .assert-table th:nth-child(2), .assert-table td:nth-child(2) { width: 10%; }
-  .assert-table th:nth-child(3), .assert-table td:nth-child(3) { width: 25%; }
-  .assert-table th:nth-child(4), .assert-table td:nth-child(4) { width: 25%; }
+  .assert-table th:nth-child(1), .assert-table td:nth-child(1) { width: 23%; }
+  .assert-table th:nth-child(2), .assert-table td:nth-child(2) { width: 15%; }
+  .assert-table th:nth-child(3), .assert-table td:nth-child(3) { width: 23%; }
+  .assert-table th:nth-child(4), .assert-table td:nth-child(4) { width: 24%; }
   .assert-table th:nth-child(5), .assert-table td:nth-child(5) { width: 15%; text-align: center; }
   .ok { color: var(--ok); }
   .err { color: var(--fail); }
@@ -691,9 +710,11 @@ def write_html(report: RunReport, outfile: str | Path) -> None:
     window.applyFilters();
   });
 })();</script>
-""")
+"""
+    head_parts.append(head_template.replace("Drun 测试报告", f"{system_name_html} 测试报告"))
     # style tag already closed in the header string above
     head_parts.append("</head><body>\n<div class='wrap'>\n  <div class='header-sticky'>\n    <div class='headbar'>\n      <h1>Drun 测试报告</h1>\n      <div class='meta'>生成时间：" + _escape_html(gen_time) + "</div>\n    </div>\n")
+    head_parts[-1] = head_parts[-1].replace("Drun 测试报告", f"{system_name_html} 测试报告")
     # Summary badges
     total = str(s.get('total', 0))
     passed = str(s.get('passed', 0))
