@@ -1,10 +1,12 @@
 from __future__ import annotations
 
 import json
+import re
 import time
 from typing import Any, Dict, List, Optional
 
 from drun.engine.http import HTTPClient
+from drun.loader.yaml_loader import strip_escape_quotes, format_variables_multiline
 from drun.models.case import Case
 from drun.models.report import AssertionResult, CaseInstanceResult, RunReport, StepResult
 from drun.models.step import Step
@@ -120,6 +122,78 @@ class Runner:
         # unsupported check format (body.* no longer supported)
         return None
 
+    def _convert_jmespath_expression(self, expr: str) -> str:
+        """
+        Convert JSONPath-like expression to JMESPath with proper quoting.
+
+        Handles field names with special characters by adding quotes.
+        Examples:
+            "headers.X-Demo-User" -> "headers.\"X-Demo-User\""
+            "json.user-name" -> "json.\"user-name\""
+            "data.normal_field" -> "data.normal_field"
+        """
+        # Split expression by dots, but preserve array access like [0]
+        parts = []
+        i = 0
+        n = len(expr)
+
+        while i < n:
+            if i + 1 < n and expr[i] == '[':
+                # Found array access, find the closing bracket
+                j = expr.find(']', i)
+                if j == -1:
+                    # No closing bracket, treat as regular character
+                    if i == 0:
+                        parts.append(expr[i:])
+                        break
+                    else:
+                        parts.append(expr[i])
+                        i += 1
+                        continue
+
+                # Extract array access part
+                array_part = expr[i:j+1]
+                parts.append(array_part)
+                i = j + 1
+
+                # Skip dot after array access if present
+                if i < n and expr[i] == '.':
+                    i += 1
+            else:
+                # Regular field access, find next dot or array access
+                j = i
+                while j < n and expr[j] != '.' and expr[j] != '[':
+                    j += 1
+
+                field_name = expr[i:j]
+                # Check if field name needs quoting (contains special chars)
+                if re.search(r'[^a-zA-Z0-9_]', field_name):
+                    field_name = f'"{field_name}"'
+                parts.append(field_name)
+
+                if j < n and expr[j] == '.':
+                    i = j + 1
+                else:
+                    i = j
+
+        # Join parts with dots for field access (array parts already include brackets)
+        result = []
+        for i, part in enumerate(parts):
+            if '[' in part and ']' in part:
+                # Array access, don't add dot before it
+                if i > 0:
+                    result[-1] = result[-1] + part
+                else:
+                    result.append(part)
+            else:
+                # Regular field access
+                if i == 0:
+                    result.append(part)
+                else:
+                    result.append('.' + part)
+
+        return ''.join(result)
+
     def _eval_extract(self, expr: Any, resp: Dict[str, Any]) -> Any:
         # Only support string expressions starting with $
         if not isinstance(expr, str):
@@ -177,7 +251,7 @@ class Runner:
         # JSON body via JSONPath-like: $.a.b or $[0].id -> jmespath a.b / [0].id
         body = resp.get("body")
         if e.startswith("$."):
-            jexpr = e[2:]
+            jexpr = self._convert_jmespath_expression(e[2:])
             # For streaming responses, try extracting from full response first
             if resp.get("is_stream"):
                 result = extract_from_body(resp, jexpr)
@@ -419,6 +493,15 @@ class Runner:
 
                 if self.log:
                     self.log.info(f"[STEP] Start: {rendered_step_name}")
+
+                    # Print step variables if present
+                    step_vars = step.variables or {}
+                    if step_vars:
+                        vars_str = format_variables_multiline(step_vars, "[STEP] variables: ")
+                        for line in vars_str.split("\n"):
+                            if line.strip():
+                                self.log.info(line)
+
                     # brief request line
                     self.log.info(f"[REQUEST] {req_rendered.get('method','GET')} {req_rendered.get('path')}")
                     if req_rendered.get("params") is not None:
@@ -563,9 +646,15 @@ class Runner:
                 step_failed = False
                 for v in step.validators:
                     rendered_check = self._render(v.check, variables, funcs, envmap)
-                    check_str = rendered_check if isinstance(rendered_check, str) else str(v.check)
+                    # If rendered_check is not a string, it's already a value (e.g., extracted variable)
+                    # Use it directly as actual instead of trying to resolve from response
+                    if not isinstance(rendered_check, str):
+                        actual = rendered_check
+                        check_str = str(v.check)
+                    else:
+                        check_str = rendered_check
+                        actual = self._resolve_check(check_str, resp_obj)
                     expect_rendered = self._render(v.expect, variables, funcs, envmap)
-                    actual = self._resolve_check(check_str, resp_obj)
                     passed, err = compare(v.comparator, actual, expect_rendered)
                     msg = err
                     if not passed and msg is None:
@@ -634,12 +723,12 @@ class Runner:
                 body_masked = resp_obj.get("body")
                 if not self.reveal:
                     body_masked = mask_body(body_masked)
-                
+
                 # Build response dict - include streaming fields if present
                 response_dict = {
                     "status_code": resp_obj.get("status_code"),
                 }
-                
+
                 # Check if streaming response
                 if resp_obj.get("is_stream"):
                     response_dict["is_stream"] = True
@@ -658,8 +747,22 @@ class Runner:
                         response_dict["stream_events"] = masked_events
                 else:
                     # Regular response body
-                    response_dict["body"] = body_masked if isinstance(body_masked, (dict, list)) else (str(body_masked)[:2048] if body_masked else None)
-                
+                    if isinstance(body_masked, (dict, list)):
+                        response_dict["body"] = body_masked
+                    elif body_masked is None:
+                        response_dict["body"] = None
+                    elif isinstance(body_masked, (str, bytes)):
+                        if isinstance(body_masked, bytes):
+                            text = body_masked.decode("utf-8", errors="replace")
+                        else:
+                            text = body_masked
+                        response_dict["body"] = text if len(text) <= 2048 else text[:2048] + "..."
+                    elif isinstance(body_masked, (bool, int, float)):
+                        response_dict["body"] = body_masked
+                    else:
+                        text = str(body_masked)
+                        response_dict["body"] = text if len(text) <= 2048 else text[:2048] + "..."
+
                 # Build curl command for the step (always available in report)
                 url_rendered = resp_obj.get("url") or req_rendered.get("path")
                 curl_headers = req_rendered.get("headers") or {}
